@@ -27,7 +27,7 @@
 
 #include "yauap.h"
 
-#define VERSION "0.2.3"
+#define VERSION "0.2.4"
 
 #define NUM_FRONTENDS 2
 yauap_frontend_t* init_commandline(int argc, char* argv[],player_t* player);
@@ -543,7 +543,9 @@ static int create_play_pipeline(player_t* player,const char* url){
     convert = gst_element_factory_make("audioconvert", "convert");
     resample = gst_element_factory_make ("audioresample", "aresample");
     priv->volume = gst_element_factory_make ("volume", "volume");
-    audiosink = gst_element_factory_make("autoaudiosink", "audiosink");
+    audiosink = gst_element_factory_make("gconfaudiosink", "audiosink");
+    if (!audiosink)
+	audiosink = gst_element_factory_make("autoaudiosink", "audiosink");
     /* clone the data for the scope */
     identity = gst_element_factory_make("identity","identity");
 
